Muhomor Micro-Services Framework
====================================

Toolset for micro-services development.
To be updated...


Installation
====================================

Via PyPI:

.. code:: bash

    pip install muhomor

